=========
EHRcorral
=========

.. image:: https://img.shields.io/travis/nsh87/ehrcorral.svg
        :target: https://travis-ci.org/nsh87/ehrcorral

.. image:: https://img.shields.io/pypi/v/ehrcorral.svg
        :target: https://pypi.python.org/pypi/ehrcorral

EHRCorral matches, links, and de-duplicates electronic medical records for
the purpose of creating a master patient index (MPI).

* Free software: ISC license
* Documentation: https://ehrcorral.readthedocs.org.

Quick Start
-----------
